"""
date routines
decimalDate - convert year, month, day, hour, minute to fractional year
calendarDate - convert fractional year to year, month, day, hour, minute
"""

###########################################################
def decimalDate(year, month, day, hour, minute):
	""" Convert calendar date to fractional year """

	x = todoy(year, month, day)
	y = hour*3600 + minute*60

	soy = (x-1)*86400 + y
	if year % 4 == 0:
		dd = year + soy/3.16224e7
	else:
		dd = year + soy/3.1536e7

	return dd

###########################################################
def todoy(year, month, day):
	""" get day of year from year, month, day """

	mona = [31, 59, 90, 120, 151, 181, 212, 243, 273, 304, 334]

	if month == 1:
		return day

	doy = mona[month-2]
	doy = doy + day
	if year % 4 == 0 and month > 2:
		doy = doy + 1
	return doy

###################################################
def calendarDate(decyear):
	""" Convert fractional year to calendar date """

	dyr = int(decyear)
	fyr = decyear - dyr

	if dyr % 4 == 0:
		nsec = int(fyr * (366.0*86400))
	else:
		nsec = int(fyr * (365.0*86400))

	ndays = nsec / 86400
	doy = ndays + 1

	month, day = to_mmdd(dyr, doy)

	nsecs = nsec - (ndays*86400)
	hour = nsecs / 3600
	minute = (nsecs - (hour *3600)) / 60
	seconds = nsecs - (hour * 3600.0) - (minute * 60.0)

	return dyr, month, day, hour, minute, seconds


###################################################
def to_mmdd(year, doy):
	""" convert day of year to month, day """

	if year % 4 == 0:
		mona = [31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]
	else:
		mona = [31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31]

	idoy = doy
	imon = 0
	while idoy - mona[imon] > 0:
		idoy = idoy - mona[imon]
		imon += 1

	month = imon + 1
	return month, idoy
